/*
 * Copyright 2007 Robert Shearman (for CodeWeavers)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 */

#define IDD_CREDDIALOG      100
#define IDC_USERNAME        101
#define IDC_PASSWORD        102
#define IDC_MESSAGE         103
#define IDC_STATIC          104
#define IDC_SAVE            105

#define IDB_BANNER          200

#define IDS_TITLEFORMAT     300
#define IDS_MESSAGEFORMAT   301
#define IDS_INCORRECTPASSWORDTITLE  302
#define IDS_INCORRECTPASSWORD       303
#define IDS_CAPSLOCKON      304
#define IDS_CAPSLOCKONTITLE 305
